@@ -43,7 +43,7 @@ SUBBRANCH_MAPS = [
                  ['trks.usr_data', 'trks.usr', 'trks.fUniqueID', 'trks.fBits'],
                  attrparser=_nested_mapper,
                  flat=False,
-                 toawkward=['usr', 'fitinf', 'rec_stages']),
+                 toawkward=['fitinf', 'rec_stages']),
     BranchMapper(name="mc_tracks",
                  key="mc_trks",
                  exclude=EXCLUDE_KEYS + [
